@@ -1,3 +1,4 @@
+import PropTypes from 'prop-types';
 import React, { Component } from 'react'
 import HeSetupWizard from './HeSetupWizard'
 import { HeSetupModel, isEmptyObject } from '../../../helpers/HostedEngineSetupUtil'
@@ -39,17 +40,19 @@ class HeSetupWizardContainer extends Component {
         let systemData = null;
         let sysDataRetrieved = false;
         let networkIfacesRetrieved = false;
+        let hostFqdnValidated = false;
 
         if (!isEmptyObject(initResults)) {
             sysDataRetrieved = initResults[tasks.GET_SYSTEM_DATA] === true;
             networkIfacesRetrieved = initResults[tasks.RETRIEVE_NETWORK_INTERFACES] === true;
+            hostFqdnValidated = initResults[tasks.VALIDATE_FQDN] === true;
         }
 
         if (sysDataRetrieved) {
             this.libvirtRunning = this.defaultsProvider.libvirtRunning();
             this.virtSupported = this.defaultsProvider.virtSupported();
             this.sufficientMemAvail = this.defaultsProvider.sufficientMemAvail();
-            this.allSystemDataRetrieved = sysDataRetrieved && networkIfacesRetrieved;
+            this.allSystemDataRetrieved = sysDataRetrieved && networkIfacesRetrieved && hostFqdnValidated;
 
             const loadingSuccessful = this.allSystemDataRetrieved && this.libvirtRunning &&
                 this.virtSupported && this.sufficientMemAvail;
@@ -120,10 +123,10 @@ class HeSetupWizardContainer extends Component {
 }
 
 HeSetupWizardContainer.propTypes = {
-    deploymentType: React.PropTypes.string,
-    gDeployAnswerFilePaths: React.PropTypes.array,
-    onClose: React.PropTypes.func.isRequired,
-    onSuccess: React.PropTypes.func.isRequired
+    deploymentType: PropTypes.string,
+    gDeployAnswerFilePaths: PropTypes.array,
+    onClose: PropTypes.func.isRequired,
+    onSuccess: PropTypes.func.isRequired
 };
 
 export default HeSetupWizardContainer;
